@@ -1,5 +1,5 @@
 use crate::ext::{AsOptExpr, PatOrExprExt};
-use fxhash::FxHashMap;
+use rustc_hash::FxHashMap;
 use swc_common::{comments::Comments, util::take::Take, Span, Spanned};
 use swc_ecma_ast::*;
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
